<?php

namespace Litecms\Diamondaffiliate\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\Diamondaffiliate\Models\DiamondAffiliate;

class DiamondAffiliatePolicy
{

    /**
     * Determine if the given user can view the diamond_affiliate.
     *
     * @param UserPolicy $user
     * @param DiamondAffiliate $diamond_affiliate
     *
     * @return bool
     */
    public function view(UserPolicy $user, DiamondAffiliate $diamond_affiliate)
    {
        if ($user->canDo('diamondaffiliate.diamond_affiliate.view') && $user->isAdmin()) {
            return true;
        }

        return $diamond_affiliate->user_id == user_id() && $diamond_affiliate->user_type == user_type();
    }

    /**
     * Determine if the given user can create a diamond_affiliate.
     *
     * @param UserPolicy $user
     * @param DiamondAffiliate $diamond_affiliate
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('diamondaffiliate.diamond_affiliate.create');
    }

    /**
     * Determine if the given user can update the given diamond_affiliate.
     *
     * @param UserPolicy $user
     * @param DiamondAffiliate $diamond_affiliate
     *
     * @return bool
     */
    public function update(UserPolicy $user, DiamondAffiliate $diamond_affiliate)
    {
        if ($user->canDo('diamondaffiliate.diamond_affiliate.edit') && $user->isAdmin()) {
            return true;
        }

        return $diamond_affiliate->user_id == user_id() && $diamond_affiliate->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given diamond_affiliate.
     *
     * @param UserPolicy $user
     * @param DiamondAffiliate $diamond_affiliate
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, DiamondAffiliate $diamond_affiliate)
    {
        return $diamond_affiliate->user_id == user_id() && $diamond_affiliate->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given diamond_affiliate.
     *
     * @param UserPolicy $user
     * @param DiamondAffiliate $diamond_affiliate
     *
     * @return bool
     */
    public function verify(UserPolicy $user, DiamondAffiliate $diamond_affiliate)
    {
        if ($user->canDo('diamondaffiliate.diamond_affiliate.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given diamond_affiliate.
     *
     * @param UserPolicy $user
     * @param DiamondAffiliate $diamond_affiliate
     *
     * @return bool
     */
    public function approve(UserPolicy $user, DiamondAffiliate $diamond_affiliate)
    {
        if ($user->canDo('diamondaffiliate.diamond_affiliate.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
